#!/bin/bash

# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


set -e

APPID=$1
TMP=$(mktemp)
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

if [[ -f $APPID ]]; then
    echo "Reading yarn logs from local file: $APPID"
    cat "$APPID" | grep HISTORY > "$TMP"
else
    YARN=$(which yarn);
    echo "Fetching yarn logs for $APPID"
    $YARN logs -applicationId "$APPID" | grep HISTORY > "$TMP"
fi
echo "History was written into $TMP"

python "$DIR/swimlane.py" -o "$APPID.svg" "$TMP"